Index: sites/trunk/wordpress.org/public_html/wp-content/plugins/wporg-bbp-topic-resolution/inc/class-plugin.php
===================================================================
--- sites/trunk/wordpress.org/public_html/wp-content/plugins/wporg-bbp-topic-resolution/inc/class-plugin.php	(revision 5289)
+++ sites/trunk/wordpress.org/public_html/wp-content/plugins/wporg-bbp-topic-resolution/inc/class-plugin.php	(working copy)
@@ -505,7 +505,7 @@
 			$post = get_post( $topic_id );
 		}
 
-		if ( $user_id && $post && ( user_can( $user_id, 'moderate' ) || $user_id == $post->post_author ) ) {
+		if ( $user_id && $post && ( user_can( $user_id, 'moderate', $topic_id ) || $user_id == $post->post_author ) ) {
 			$retval = true;
 		} else {
 			$retval = false;
Index: sites/trunk/wordpress.org/public_html/wp-content/plugins/wporg-bbp-user-badges/inc/class-plugin.php
===================================================================
--- sites/trunk/wordpress.org/public_html/wp-content/plugins/wporg-bbp-user-badges/inc/class-plugin.php	(revision 5289)
+++ sites/trunk/wordpress.org/public_html/wp-content/plugins/wporg-bbp-user-badges/inc/class-plugin.php	(working copy)
@@ -386,7 +386,7 @@
 	 * of badging them. Use the $strict argument to check that the user is a
 	 * moderator without considering if they are a keymaster.
 	 *
 	 * @param string $user_id Optional. User ID. Assumes current reply author ID
 	 *                        if not provided.
 	 * @param bool   $strict  Optional. True if user should strictly be checked
 	 *                        for being a moderator, false will also check if they
@@ -395,9 +395,9 @@
 	 */
 	public function is_user_moderator( $user_id = '', $strict = false ) {
 		if ( ! $user_id ) {
-			$user_id = bbp_get_reply_author_id();
+			$user_id = get_post_field( 'post_author' );
 		}
 
-		return ( user_can( $user_id, 'moderate' ) || ( ! $strict && bbp_is_user_keymaster( $user_id ) ) );
+		return ( user_can( $user_id, 'moderate', get_the_ID() ) || ( ! $strict && bbp_is_user_keymaster( $user_id ) ) );
 	}
 }
@@ -386,7 +386,7 @@
 	 * moderator without considering if they are a keymaster.
 	 *
-	 * @param string $user_id Optional. User ID. Assumes current reply author ID
+	 * @param string $user_id Optional. User ID. Assumes current post author ID
 	 *                        if not provided.
 	 * @param bool   $strict  Optional. True if user should strictly be checked
